<?php
namespace Ep\Wp;

use Ep\Cache\AbstractCacheFactory;
use Zend\ServiceManager\AbstractFactory\ReflectionBasedAbstractFactory;
use Zend\ServiceManager\Factory\InvokableFactory;

/**
 * Class ConfigProvider
 *
 * @package Ep\Wp
 * @author Elektronika Perhoč <support@ep.hr>
 * @link https://bitbucket.org/elektronika-perhoc/ep-wordpress
 */
class ConfigProvider
{
    /**
     * Vraća konfiguraciju.
     *
     * @return array
     */
    public function __invoke()
    {
        return [
            'dependencies' => [
                'aliases' => [
                    'wp'           => WordPress::class,
                    'wp.constants' => Middleware\Constants::class,
                    'wp.database'  => Middleware\Database::class,
                    'wp.plugins'   => Middleware\Plugins::class,
                    'wp.runner'    => Middleware\Runner::class,
                ],

                'factories' => [
                    WordPress::class            => ReflectionBasedAbstractFactory::class,
                    Middleware\Constants::class => ReflectionBasedAbstractFactory::class,
                    Middleware\Database::class  => ReflectionBasedAbstractFactory::class,
                    Middleware\Plugins::class   => ReflectionBasedAbstractFactory::class,
                    Middleware\Runner::class    => ReflectionBasedAbstractFactory::class,

                    Plugin\TranslationCache::CACHE_NAME => AbstractCacheFactory::class,
                    Plugin\TwigExtension::class         => InvokableFactory::class,
                ],
            ],

            'caches' => [
                Plugin\TranslationCache::CACHE_NAME => [
                    'adapter' => 'null',
                    'options' => [
                        'namespace' => Plugin\TranslationCache::CACHE_NAMESPACE,
                        'default_lifetime' => 0,
                    ],
                ],
            ],

            'twig' => [
                'extensions' => [
                    Plugin\TwigExtension::class,
                ],
            ],

            'wp' => [
                'admin_only'   => false,
                'debug'        => false,
                'load_theme'   => true,
                'table_prefix' => 'wp_',

                /**
                 * {@link https://api.wordpress.org/secret-key/1.1/salt/ WordPress.org secret-key service}
                 */
                'auth_key'         => '',
                'secure_auth_key'  => '',
                'logged_in_key'    => '',
                'nonce_key'        => '',
                'auth_salt'        => '',
                'secure_auth_salt' => '',
                'logged_in_salt'   => '',
                'nonce_salt'       => '',
            ],
        ];
    }
}