<?php
namespace Ep\Wp\Middleware;

use Interop\Http\Server\MiddlewareInterface;
use Interop\Http\Server\RequestHandlerInterface;
use Psr\Http\Message\ResponseInterface;
use Psr\Http\Message\ServerRequestInterface;
use Zend\Diactoros\Response\HtmlResponse;

/**
 * Pokreće WordPress.
 *
 * @package Ep\Wp\Middleware
 * @author Elektronika Perhoč <support@ep.hr>
 * @link https://bitbucket.org/elektronika-perhoc/ep-wordpress
 */
class Runner implements MiddlewareInterface
{
    /** @var array */
    private $config;

    /**
     * Runner constructor.
     *
     * @param array $config
     */
    public function __construct(array $config)
    {
        $this->config = $config['wp'] ?? [];
    }

    /**
     * Pokreće WordPress, ili bolje rečeno, nastavlja izvršavanje.
     *
     * @param ServerRequestInterface $request
     * @param RequestHandlerInterface $handler
     *
     * @return ResponseInterface
     */
    public function process(ServerRequestInterface $request, RequestHandlerInterface $handler)
    {
        if (!$this->config['load_theme'] ?? true) {
            define('EP_TEMPLATE_LOADER', true);
        }

        /** @noinspection PhpUnusedLocalVariableInspection */
        global $wc_cpdf, $extensions_uri;

        /** @noinspection PhpUnusedLocalVariableInspection */
        $table_prefix = $this->config['table_prefix'] ?? 'wp_';

        ob_start();
        include ABSPATH . 'wp-settings.php';
        $output = ob_get_clean();

        if (!defined('EP_TEMPLATE_LOADER') || !defined('WP_USE_THEMES')) {
            return new HtmlResponse($output);
        }

        return $handler->handle($request);
    }
}