<?php
namespace Ep\Wp;

use Ep\Middleware\BaseUrl;
use Psr\Container\ContainerInterface;
use Psr\Http\Message\ResponseInterface;
use Psr\Http\Message\ServerRequestInterface;
use /** @noinspection PhpUndefinedClassInspection */
    Webimpress\HttpMiddlewareCompatibility\HandlerInterface as DelegateInterface;
use Zend\Stratigility\MiddlewarePipe;
use Zend\Stratigility\Next;

/**
 * WordPress Middleware.
 *
 * Ovaj middleware je potrebno pokrenuti umjesto wp-config.php datoteke.
 *
 * @package Ep\WordPress
 * @author Elektronika Perhoč <support@ep.hr>
 * @link https://bitbucket.org/elektronika-perhoc/ep-wordpress
 */
class WordPress extends MiddlewarePipe
{
    /** @var array */
    private $config;

    /**
     * WordPress constructor.
     *
     * @param ContainerInterface $container
     * @param array $config
     */
    public function __construct(ContainerInterface $container, array $config)
    {
        parent::__construct();

        $this->config = $config['wp'] ?? [];

        $this->pipe($container->get('wp.database'));
        $this->pipe($container->get('wp.constants'));
        $this->pipe($container->get('wp.plugins'));
        $this->pipe($container->get('wp.runner'));
    }/** @noinspection PhpUndefinedClassInspection */

    /**
     * @param ServerRequestInterface $request
     * @param DelegateInterface|Next $delegate
     *
     * @return ResponseInterface
     */
    public function process( ServerRequestInterface $request, /** @noinspection PhpUndefinedClassInspection */
        DelegateInterface $delegate)
    {
        if ($this->config['admin_only'] ?? false) {
            $baseUrl = $request->getAttribute(BaseUrl::BASE_URL);

            if (!preg_match('#/wp(/|$)#', $baseUrl)) {
                return $delegate->handle($request);
            }
        }

        return parent::process($request, $delegate);
    }
}